package org.snowchen.GreatSonServer.programinit;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.sql.*;
import java.util.Arrays;
import java.util.Scanner;
import java.util.UUID;

public class UserRegister {
    private Scanner scan = new Scanner(System.in);
    private String user_name;
    private String user_password;
    private String uuid;
    private String user_register_time;
    private int user_permission_level;
    private String[] UserData; // 将UserData数组定义为私有

    public UserRegister() {
        UserData = new String[5];
        // 用户信息初始化
        System.out.println("请输入用户名:");
        this.user_name = scan.nextLine();
        while (this.user_name.isEmpty()) {
            System.out.println("用户名不能为空，请重新输入:");
            this.user_name = scan.nextLine();
        }
        UserData[0] = this.user_name;
        System.out.println("请输入密码:");
        this.user_password = scan.nextLine();
        while (!isStrongPassword(this.user_password)) {
            System.out.println("密码需为8位以上大小写字母和数字组合，请重新输入:");
            this.user_password = scan.nextLine();
        }
        // 使用SHA-256加密密码
        try {
            this.user_password = hashPassword(this.user_password);
        } catch (NoSuchAlgorithmException e) {
            System.err.println("加密错误: " + e.getMessage());
        }
        UserData[1] = this.user_password;
        this.uuid = UUID.randomUUID().toString(); // 使用标准的 UUID 生成方法
        UserData[2] = this.uuid;
        this.user_permission_level = 0;
        UserData[3] = String.valueOf(this.user_permission_level);
        this.user_register_time = String.valueOf(System.nanoTime());
        UserData[4] = this.user_register_time;
        System.out.println("用户名:" + this.user_name + "\n密码:" + this.user_password + "\nuuid:" + this.uuid + "\n注册时间:" + this.user_register_time);
        System.out.println("UserData: " + Arrays.toString(UserData));
        insertUserData(UserData);
    }

    // 提供一个公共方法来获取UserData数组
    public String[] getUserData() {
        return UserData;
    }

    public void insertUserData(String[] UserData) {
        String url = "jdbc:sqlite:test.db"; // SQLite数据库URL
        String sql = "INSERT INTO user_data (user_name, user_password, user_uuid, user_permission_level, user_register_time) VALUES (?, ?, ?, ?, ?)";

        try (Connection conn = DriverManager.getConnection(url);
             PreparedStatement pstmt = conn.prepareStatement(sql)) {

            pstmt.setString(1, UserData[0]);
            pstmt.setString(2, UserData[1]);
            pstmt.setString(3, UserData[2]);
            pstmt.setInt(4, Integer.parseInt(UserData[3])); // 假设user_permission_level是整数
            pstmt.setString(5, UserData[4]); // 假设user_register_time是字符串形式的纳秒时间戳

            int affectedRows = pstmt.executeUpdate();
            if (affectedRows > 0) {
                System.out.println("用户数据插入成功");
            } else {
                System.out.println("用户数据插入失败");
            }
        } catch (SQLException e) {
            System.err.println("数据库错误: " + e.getMessage());
        } catch (Exception e) {
            System.err.println("错误: " + e.getMessage());
        }
    }

    private static final String PWD_REGEX = "^(?=.*[a-z])(?=.*[A-Z])(?=.*\\d).{8,}$";

    /**
     * 检测密码是否为强密码
     * 强密码的定义基于预设的正则表达式PWD_REGEX，该表达式代表了密码的复杂性要求
     *
     * @param password 待检测的密码字符串
     * @return 如果密码符合强密码的要求且不为空字符串，则返回true；否则返回false
     */
    public static boolean isStrongPassword(String password) {
        // 密码强度检测
        if (password == null || password.trim().isEmpty()) {
            return false;
        }
        return password.matches(PWD_REGEX);
    }

    /**
     * 使用SHA-256算法加密密码
     *
     * @param password 待加密的密码字符串
     * @return 加密后的密码字符串
     * @throws NoSuchAlgorithmException 如果指定的算法不存在
     */
    public static String hashPassword(String password) throws NoSuchAlgorithmException {
        MessageDigest md = MessageDigest.getInstance("SHA-256");
        byte[] hashedPassword = md.digest(password.getBytes());
        StringBuilder sb = new StringBuilder();
        for (byte b : hashedPassword) {
            sb.append(String.format("%02x", b));
        }
        return sb.toString();
    }
}



